@@ -4,7 +4,7 @@ from diningcodeapi.config import HEADERS
 
 
 class ThemeMixin:
-    def get_themes(self, region: str, page_no: int, proxy=None):
+    def get_themes(self, region: str, page_no: int, proxies=None):
         url = f"https://im.diningcode.com/API/recommend/"
         data = {
             "lat": "",
@@ -14,9 +14,9 @@ class ThemeMixin:
             "token": "",
             "session": {"type": "area", "area": "서울", "hour": 15},
             "mode": "home",
-            "device": "web"
+            "device": "web",
         }
-        response = requests.post(url, data=data, headers=HEADERS, proxies={"http": proxy})
+        response = requests.post(url, data=data, headers=HEADERS, proxies=proxies)
         response.raise_for_status()
         themes = response.json()
 
